/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.test.transactions;


/**
 * Interfaces to be implemented by resource that want to participate in transactions
 * managed through {@link SimpleTransactionManager}.
 * 
 * @author Erik Brakkee
 *
 * @param <T>
 */
public interface TransactionResource<T> {

    /**
     * Begins a transaction. 
     * @return Object that manages the transaction for the resource.
     */
    T begin(); 
    
    /**
     * Rolls back a transaction.
     * @param aT Object that manages the transaction for the resource. 
     */
    void rollback(T aT); 
    
    /**
     * Commits the transaction. 
     * @param aT Object that manages the transaction for the resource. 
     */
    void commit(T aT);
    
}
